@@ -7,44 +7,36 @@ from telegrambotclient.storage import TelegramStorage
 class TelegramBotClient:
     __slots__ = ("bots", "routers", "name", "api_callers")
 
-    def __init__(self, name: str = "bot-client") -> None:
+    def __init__(self, name: str = None):
         self.bots = {}
         self.routers = {}
         self.api_callers = {}
-        self.name = name
+        self.name = name or "default"
 
-    def router(self, name: str = "bot-router") -> TelegramRouter:
-        router = self.routers.get(name, None)
+    def router(self, name: str = None) -> TelegramRouter:
+        router = self.routers.get(name or "default", None)
         if router is None:
             self.routers[name] = TelegramRouter(name)
-        return self.routers[name]
+            return self.routers[name]
+        return router
 
     def create_bot(self,
                    token: str,
-                   router: TelegramRouter = None,
                    bot_api: TelegramBotAPI = None,
                    storage: TelegramStorage = None,
                    i18n_source=None,
                    session_expires: int = 1800) -> TelegramBot:
 
-        router = router or self.router()
-        if router.name not in self.routers:
-            self.routers[router.name] = router
         bot_api = self.api_callers.get(
             bot_api.host if bot_api else TelegramBotAPI.DEFAULT_API_HOST, None)
         if bot_api is None:
             bot_api = TelegramBotAPI()
             self.api_callers[bot_api.host] = bot_api
-        bot = TelegramBot(token, router, bot_api, storage, i18n_source,
+        bot = TelegramBot(token, bot_api, storage, i18n_source,
                           session_expires)
         self.bots[token] = bot
         return bot
 
-    async def dispatch(self, token: str, raw_update):
-        bot = self.bots.get(token, None)
-        if bot:
-            await bot.dispatch(raw_update)
-
 
 # default bot proxy
 bot_client = TelegramBotClient()
